@@ -9,7 +9,7 @@ class NeuMangaTv(Provider, Std):
         idx = self.re.search(r'/manga/[^/]+/(\d+(?:\+\d+))', chapter).group(1)
         return '-'.join(idx.split('+'))
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga/{}')
 
     def get_manga_name(self) -> str:
